﻿// --------------------------------------------------------------------------------------------------------------------
// <copyright file="ShellWindow.cs" company="HandBrake Project (http://handbrake.fr)">
//   This file is part of the HandBrake source code - It may be used under the terms of the GNU General Public License.
// </copyright>
// <summary>
//   The Window that the shell view can display
// </summary>
// --------------------------------------------------------------------------------------------------------------------

namespace HandBrakeWPF.Model
{
    /// <summary>
    /// The Window that the shell view can display
    /// </summary>
    public enum ShellWindow
    {
        MainWindow,
        OptionsWindow,
        InstantMainWindow
    }
}
